@@ -22,14 +22,14 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2',
+           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -37,9 +37,9 @@ build_time_vars = {'ABIFLAGS': '',
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                     '--param=ssp-buffer-size=4 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2',
+                     '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -47,7 +47,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
                 "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python38' "
                 "'--htmldir=/usr/share/doc/python38/html' '-C' "
@@ -57,19 +57,19 @@ build_time_vars = {'ABIFLAGS': '',
                 "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' "
                 "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
                 '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                '--param=ssp-buffer-size=4 '
-                '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                "-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2' "
+                '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                "-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pub/devel/python/python38/python38-3.8.9-2.i686/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python38/python38-3.8.9-2.i686/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python38/python38-3.8.10-1.i686/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python38/python38-3.8.10-1.i686/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include',
+             '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
  'DESTLIB': '/usr/lib/python3.8',
@@ -181,6 +181,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 1,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 0,
@@ -568,6 +569,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '',
  'LIPO_32BIT_FLAGS': '',
+ 'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
@@ -580,7 +582,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Modules/makesetup',
+ 'MAKESETUP': '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -645,59 +647,59 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fwrapv -O3 -Wall -ggdb -O2 -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                             '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                              '-ggdb -O2 -pipe -Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                             '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration  '
-                             '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include/internal '
+                             '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include '
+                             '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2',
+              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
-                     '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include/internal',
+                     '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                   '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                   '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                   '--param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                   '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
-                   '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include/internal '
+                   '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include '
+                   '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include',
+                '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -707,19 +709,20 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall -ggdb -O2 -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                        '-DOPENSSL_NO_SSL3=1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                         '-ggdb -O2 -pipe -Wall -Werror=format-security '
                         '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                        '--param=ssp-buffer-size=4 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/build=/usr/src/debug/python38-3.8.9-2 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9=/usr/src/debug/python38-3.8.9-2 '
+                        '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/build=/usr/src/debug/python38-3.8.10-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10=/usr/src/debug/python38-3.8.10-1 '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
-                        '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include/internal '
+                        '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Include',
+                        '-I/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -758,7 +761,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-38-i386-cygwin',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -773,7 +776,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -781,10 +784,10 @@ build_time_vars = {'ABIFLAGS': '',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.8 '
-                '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9/Tools/scripts/update_file.py',
+                '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.8',
- 'VPATH': '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9',
+ 'VPATH': '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -796,9 +799,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python38/python38-3.8.9-2.i686/build',
- 'abs_srcdir': '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9',
+ 'abs_builddir': '/pub/devel/python/python38/python38-3.8.10-1.i686/build',
+ 'abs_srcdir': '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python38/python38-3.8.9-2.i686/src/Python-3.8.9'}
+ 'srcdir': '/pub/devel/python/python38/python38-3.8.10-1.i686/src/Python-3.8.10'}
